@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 2.0.  */
+/* A Bison parser, made by GNU Bison 1.875c.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -260,7 +260,7 @@ typedef union YYSTYPE {
     int num;
     char *ptr;
 } YYSTYPE;
-/* Line 190 of yacc.c.  */
+/* Line 191 of yacc.c.  */
 #line 265 "gram.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -272,26 +272,23 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 213 of yacc.c.  */
+/* Line 214 of yacc.c.  */
 #line 277 "gram.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
-# ifndef YYFREE
-#  define YYFREE free
-# endif
-# ifndef YYMALLOC
-#  define YYMALLOC malloc
-# endif
-
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
 # ifdef YYSTACK_USE_ALLOCA
 #  if YYSTACK_USE_ALLOCA
+#   define YYSTACK_ALLOC alloca
+#  endif
+# else
+#  if defined (alloca) || defined (_ALLOCA_H)
+#   define YYSTACK_ALLOC alloca
+#  else
 #   ifdef __GNUC__
 #    define YYSTACK_ALLOC __builtin_alloca
-#   else
-#    define YYSTACK_ALLOC alloca
 #   endif
 #  endif
 # endif
@@ -304,8 +301,8 @@ typedef union YYSTYPE {
 #   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
 #   define YYSIZE_T size_t
 #  endif
-#  define YYSTACK_ALLOC YYMALLOC
-#  define YYSTACK_FREE YYFREE
+#  define YYSTACK_ALLOC malloc
+#  define YYSTACK_FREE free
 # endif
 #endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */
 
@@ -317,7 +314,7 @@ typedef union YYSTYPE {
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  short int yyss;
+  short yyss;
   YYSTYPE yyvs;
   };
 
@@ -327,7 +324,7 @@ union yyalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
+     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
@@ -369,7 +366,7 @@ union yyalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char yysigned_char;
 #else
-   typedef short int yysigned_char;
+   typedef short yysigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -434,7 +431,7 @@ static const unsigned char yytranslate[] =
 #if YYDEBUG
 /* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
    YYRHS.  */
-static const unsigned short int yyprhs[] =
+static const unsigned short yyprhs[] =
 {
        0,     0,     3,     5,     6,     9,    11,    13,    15,    17,
       19,    26,    30,    33,    36,    38,    41,    44,    45,    49,
@@ -459,7 +456,7 @@ static const unsigned short int yyprhs[] =
 };
 
 /* YYRHS -- A `-1'-separated list of the rules' RHS. */
-static const short int yyrhs[] =
+static const short yyrhs[] =
 {
       76,     0,    -1,    77,    -1,    -1,    77,    78,    -1,     1,
       -1,   100,    -1,   101,    -1,   102,    -1,   127,    -1,    36,
@@ -518,7 +515,7 @@ static const short int yyrhs[] =
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
-static const unsigned short int yyrline[] =
+static const unsigned short yyrline[] =
 {
        0,   133,   133,   136,   137,   140,   141,   142,   143,   144,
      145,   147,   153,   156,   162,   164,   165,   166,   166,   168,
@@ -581,7 +578,7 @@ static const char *const yytname[] =
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short int yytoknum[] =
+static const unsigned short yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
      265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
@@ -681,7 +678,7 @@ static const unsigned char yydefact[] =
 };
 
 /* YYDEFGOTO[NTERM-NUM]. */
-static const short int yydefgoto[] =
+static const short yydefgoto[] =
 {
       -1,     1,     2,    42,    73,    74,    70,    68,    65,    82,
       77,    89,    75,    71,    81,    76,   267,    97,   107,    59,
@@ -696,7 +693,7 @@ static const short int yydefgoto[] =
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
 #define YYPACT_NINF -159
-static const short int yypact[] =
+static const short yypact[] =
 {
     -159,    15,   265,  -159,  -159,   -56,   -30,   -25,    28,    30,
     -159,  -159,    32,  -159,   -56,  -159,   -25,   -30,  -159,   -56,
@@ -730,7 +727,7 @@ static const short int yypact[] =
 };
 
 /* YYPGOTO[NTERM-NUM].  */
-static const short int yypgoto[] =
+static const short yypgoto[] =
 {
     -159,  -159,  -159,  -159,  -159,  -159,  -159,  -159,  -159,  -159,
     -159,  -159,  -159,  -159,  -159,  -159,  -159,  -159,  -159,  -159,
@@ -747,7 +744,7 @@ static const short int yypgoto[] =
    number is the opposite.  If zero, do what YYDEFACT says.
    If YYTABLE_NINF, syntax error.  */
 #define YYTABLE_NINF -161
-static const short int yytable[] =
+static const short yytable[] =
 {
       49,    67,   154,    66,   188,   196,   199,   203,   209,    64,
      279,   191,   149,   106,    69,     3,   261,   262,    41,    90,
@@ -785,7 +782,7 @@ static const short int yytable[] =
        0,     0,    37,     0,     0,    38,    39,     0,    40,    41
 };
 
-static const short int yycheck[] =
+static const short yycheck[] =
 {
        5,    17,     4,    16,     4,     4,     4,     4,     4,    14,
        4,     4,     4,    63,    19,     0,    11,    12,    74,    47,
@@ -909,53 +906,20 @@ do								\
     }								\
 while (0)
 
-
 #define YYTERROR	1
 #define YYERRCODE	256
 
+/* YYLLOC_DEFAULT -- Compute the default location (before the actions
+   are run).  */
 
-/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
-   If N is 0, then set CURRENT to the empty location which ends
-   the previous symbol: RHS[0] (always defined).  */
-
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (N)								\
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
-    while (0)
+# define YYLLOC_DEFAULT(Current, Rhs, N)		\
+   ((Current).first_line   = (Rhs)[1].first_line,	\
+    (Current).first_column = (Rhs)[1].first_column,	\
+    (Current).last_line    = (Rhs)[N].last_line,	\
+    (Current).last_column  = (Rhs)[N].last_column)
 #endif
 
-
-/* YY_LOCATION_PRINT -- Print the location on the stream.
-   This macro was not mandated originally: define only if we know
-   we won't break user code: when these are the locations we know.  */
-
-#ifndef YY_LOCATION_PRINT
-# if YYLTYPE_IS_TRIVIAL
-#  define YY_LOCATION_PRINT(File, Loc)			\
-     fprintf (File, "%d.%d-%d.%d",			\
-              (Loc).first_line, (Loc).first_column,	\
-              (Loc).last_line,  (Loc).last_column)
-# else
-#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
-# endif
-#endif
-
-
 /* YYLEX -- calling `yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -978,13 +942,19 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
+# define YYDSYMPRINT(Args)			\
+do {						\
+  if (yydebug)					\
+    yysymprint Args;				\
+} while (0)
+
+# define YYDSYMPRINTF(Title, Token, Value, Location)		\
 do {								\
   if (yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
       yysymprint (stderr, 					\
-                  Type, Value);	\
+                  Token, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
@@ -996,12 +966,12 @@ do {								\
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yy_stack_print (short int *bottom, short int *top)
+yy_stack_print (short *bottom, short *top)
 #else
 static void
 yy_stack_print (bottom, top)
-    short int *bottom;
-    short int *top;
+    short *bottom;
+    short *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -1051,7 +1021,8 @@ do {					\
 int yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
+# define YYDSYMPRINT(Args)
+# define YYDSYMPRINTF(Title, Token, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -1069,6 +1040,10 @@ int yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
+#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
+# undef YYMAXDEPTH
+#endif
+
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -1150,15 +1125,15 @@ yysymprint (yyoutput, yytype, yyvaluep)
   (void) yyvaluep;
 
   if (yytype < YYNTOKENS)
-    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
+    {
+      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
+# ifdef YYPRINT
+      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+# endif
+    }
   else
     YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
-
-# ifdef YYPRINT
-  if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
-# endif
   switch (yytype)
     {
       default:
@@ -1174,11 +1149,10 @@ yysymprint (yyoutput, yytype, yyvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
+yydestruct (int yytype, YYSTYPE *yyvaluep)
 #else
 static void
-yydestruct (yymsg, yytype, yyvaluep)
-    const char *yymsg;
+yydestruct (yytype, yyvaluep)
     int yytype;
     YYSTYPE *yyvaluep;
 #endif
@@ -1186,10 +1160,6 @@ yydestruct (yymsg, yytype, yyvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) yyvaluep;
 
-  if (!yymsg)
-    yymsg = "Deleting";
-  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
-
   switch (yytype)
     {
 
@@ -1217,10 +1187,10 @@ int yyparse ();
 
 
 
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1256,7 +1226,7 @@ yyparse ()
   int yyresult;
   /* Number of tokens to shift before error messages enabled.  */
   int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
+  /* Lookahead token as an internal (translated) token number.  */
   int yytoken = 0;
 
   /* Three stacks and their tools:
@@ -1268,9 +1238,9 @@ yyparse ()
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short int yyssa[YYINITDEPTH];
-  short int *yyss = yyssa;
-  register short int *yyssp;
+  short	yyssa[YYINITDEPTH];
+  short *yyss = yyssa;
+  register short *yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE yyvsa[YYINITDEPTH];
@@ -1307,9 +1277,6 @@ yyparse ()
   yyssp = yyss;
   yyvsp = yyvs;
 
-
-  yyvsp[0] = yylval;
-
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1335,7 +1302,7 @@ yyparse ()
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *yyvs1 = yyvs;
-	short int *yyss1 = yyss;
+	short *yyss1 = yyss;
 
 
 	/* Each stack pointer address is followed by the size of the
@@ -1363,7 +1330,7 @@ yyparse ()
 	yystacksize = YYMAXDEPTH;
 
       {
-	short int *yyss1 = yyss;
+	short *yyss1 = yyss;
 	union yyalloc *yyptr =
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
@@ -1399,18 +1366,18 @@ yyparse ()
 yybackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a look-ahead token if we need one and don't already have one.  */
+/* Read a lookahead token if we need one and don't already have one.  */
 /* yyresume: */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
 
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1425,7 +1392,7 @@ yybackup:
   else
     {
       yytoken = YYTRANSLATE (yychar);
-      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
+      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1445,8 +1412,8 @@ yybackup:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the look-ahead token.  */
-  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
+  /* Shift the lookahead token.  */
+  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));
 
   /* Discard the token being shifted unless it is eof.  */
   if (yychar != YYEOF)
@@ -1497,15 +1464,15 @@ yyreduce:
     {
         case 10:
 #line 146 "gram.y"
-    { AddIconRegion((yyvsp[-4].ptr), (yyvsp[-3].num), (yyvsp[-2].num), (yyvsp[-1].num), (yyvsp[0].num)); }
+    { AddIconRegion(yyvsp[-4].ptr, yyvsp[-3].num, yyvsp[-2].num, yyvsp[-1].num, yyvsp[0].num); }
     break;
 
   case 11:
 #line 147 "gram.y"
     { if (Scr->FirstTime)
 						  {
-						    Scr->iconmgr.geometry=(yyvsp[-1].ptr);
-						    Scr->iconmgr.columns=(yyvsp[0].num);
+						    Scr->iconmgr.geometry=yyvsp[-1].ptr;
+						    Scr->iconmgr.columns=yyvsp[0].num;
 						  }
 						}
     break;
@@ -1513,7 +1480,7 @@ yyreduce:
   case 12:
 #line 153 "gram.y"
     { if (Scr->FirstTime)
-						    Scr->iconmgr.geometry = (yyvsp[0].ptr);
+						    Scr->iconmgr.geometry = yyvsp[0].ptr;
 						}
     break;
 
@@ -1522,7 +1489,7 @@ yyreduce:
     { if (Scr->FirstTime)
 					  {
 						Scr->DoZoom = TRUE;
-						Scr->ZoomCount = (yyvsp[0].num);
+						Scr->ZoomCount = yyvsp[0].num;
 					  }
 					}
     break;
@@ -1557,39 +1524,39 @@ yyreduce:
   case 20:
 #line 170 "gram.y"
     { 
-					  GotTitleButton ((yyvsp[-2].ptr), (yyvsp[0].num), False);
+					  GotTitleButton (yyvsp[-2].ptr, yyvsp[0].num, False);
 					}
     break;
 
   case 21:
 #line 173 "gram.y"
     { 
-					  GotTitleButton ((yyvsp[-2].ptr), (yyvsp[0].num), True);
+					  GotTitleButton (yyvsp[-2].ptr, yyvsp[0].num, True);
 					}
     break;
 
   case 22:
 #line 176 "gram.y"
-    { root = GetRoot((yyvsp[0].ptr), NULLSTR, NULLSTR);
-					  Scr->Mouse[(yyvsp[-1].num)][C_ROOT][0].func = F_MENU;
-					  Scr->Mouse[(yyvsp[-1].num)][C_ROOT][0].menu = root;
+    { root = GetRoot(yyvsp[0].ptr, NULLSTR, NULLSTR);
+					  Scr->Mouse[yyvsp[-1].num][C_ROOT][0].func = F_MENU;
+					  Scr->Mouse[yyvsp[-1].num][C_ROOT][0].menu = root;
 					}
     break;
 
   case 23:
 #line 180 "gram.y"
-    { Scr->Mouse[(yyvsp[-1].num)][C_ROOT][0].func = (yyvsp[0].num);
-					  if ((yyvsp[0].num) == F_MENU)
+    { Scr->Mouse[yyvsp[-1].num][C_ROOT][0].func = yyvsp[0].num;
+					  if (yyvsp[0].num == F_MENU)
 					  {
 					    pull->prev = NULL;
-					    Scr->Mouse[(yyvsp[-1].num)][C_ROOT][0].menu = pull;
+					    Scr->Mouse[yyvsp[-1].num][C_ROOT][0].menu = pull;
 					  }
 					  else
 					  {
 					    root = GetRoot(TWM_ROOT,NULLSTR,NULLSTR);
-					    Scr->Mouse[(yyvsp[-1].num)][C_ROOT][0].item = 
+					    Scr->Mouse[yyvsp[-1].num][C_ROOT][0].item = 
 						AddToMenu(root,"x",Action,
-							  NULL,(yyvsp[0].num),NULLSTR,NULLSTR);
+							  NULL,yyvsp[0].num,NULLSTR,NULLSTR);
 					  }
 					  Action = "";
 					  pull = NULL;
@@ -1598,12 +1565,12 @@ yyreduce:
 
   case 24:
 #line 196 "gram.y"
-    { GotKey((yyvsp[-1].ptr), (yyvsp[0].num)); }
+    { GotKey(yyvsp[-1].ptr, yyvsp[0].num); }
     break;
 
   case 25:
 #line 197 "gram.y"
-    { GotButton((yyvsp[-1].num), (yyvsp[0].num)); }
+    { GotButton(yyvsp[-1].num, yyvsp[0].num); }
     break;
 
   case 26:
@@ -1693,7 +1660,7 @@ yyreduce:
   case 53:
 #line 229 "gram.y"
     {
-					root = GetRoot((yyvsp[-5].ptr), (yyvsp[-3].ptr), (yyvsp[-1].ptr)); }
+					root = GetRoot(yyvsp[-5].ptr, yyvsp[-3].ptr, yyvsp[-1].ptr); }
     break;
 
   case 54:
@@ -1703,7 +1670,7 @@ yyreduce:
 
   case 55:
 #line 232 "gram.y"
-    { root = GetRoot((yyvsp[0].ptr), NULLSTR, NULLSTR); }
+    { root = GetRoot(yyvsp[0].ptr, NULLSTR, NULLSTR); }
     break;
 
   case 56:
@@ -1713,7 +1680,7 @@ yyreduce:
 
   case 57:
 #line 234 "gram.y"
-    { root = GetRoot((yyvsp[0].ptr), NULLSTR, NULLSTR); }
+    { root = GetRoot(yyvsp[0].ptr, NULLSTR, NULLSTR); }
     break;
 
   case 59:
@@ -1738,8 +1705,8 @@ yyreduce:
 
   case 68:
 #line 246 "gram.y"
-    { Scr->DefaultFunction.func = (yyvsp[0].num);
-					  if ((yyvsp[0].num) == F_MENU)
+    { Scr->DefaultFunction.func = yyvsp[0].num;
+					  if (yyvsp[0].num == F_MENU)
 					  {
 					    pull->prev = NULL;
 					    Scr->DefaultFunction.menu = pull;
@@ -1749,7 +1716,7 @@ yyreduce:
 					    root = GetRoot(TWM_ROOT,NULLSTR,NULLSTR);
 					    Scr->DefaultFunction.item = 
 						AddToMenu(root,"x",Action,
-							  NULL,(yyvsp[0].num), NULLSTR, NULLSTR);
+							  NULL,yyvsp[0].num, NULLSTR, NULLSTR);
 					  }
 					  Action = "";
 					  pull = NULL;
@@ -1758,11 +1725,11 @@ yyreduce:
 
   case 69:
 #line 262 "gram.y"
-    { Scr->WindowFunction.func = (yyvsp[0].num);
+    { Scr->WindowFunction.func = yyvsp[0].num;
 					   root = GetRoot(TWM_ROOT,NULLSTR,NULLSTR);
 					   Scr->WindowFunction.item = 
 						AddToMenu(root,"x",Action,
-							  NULL,(yyvsp[0].num), NULLSTR, NULLSTR);
+							  NULL,yyvsp[0].num, NULLSTR, NULLSTR);
 					   Action = "";
 					   pull = NULL;
 					}
@@ -1786,11 +1753,11 @@ yyreduce:
 
   case 75:
 #line 279 "gram.y"
-    { if (!do_single_keyword ((yyvsp[0].num))) {
+    { if (!do_single_keyword (yyvsp[0].num)) {
 					    twmrc_error_prefix();
 					    fprintf (stderr,
 					"unknown singleton keyword %d\n",
-						     (yyvsp[0].num));
+						     yyvsp[0].num);
 					    ParseError = 1;
 					  }
 					}
@@ -1798,11 +1765,11 @@ yyreduce:
 
   case 76:
 #line 289 "gram.y"
-    { if (!do_string_keyword ((yyvsp[-1].num), (yyvsp[0].ptr))) {
+    { if (!do_string_keyword (yyvsp[-1].num, yyvsp[0].ptr)) {
 					    twmrc_error_prefix();
 					    fprintf (stderr,
 				"unknown string keyword %d (value \"%s\")\n",
-						     (yyvsp[-1].num), (yyvsp[0].ptr));
+						     yyvsp[-1].num, yyvsp[0].ptr);
 					    ParseError = 1;
 					  }
 					}
@@ -1810,11 +1777,11 @@ yyreduce:
 
   case 77:
 #line 299 "gram.y"
-    { if (!do_number_keyword ((yyvsp[-1].num), (yyvsp[0].num))) {
+    { if (!do_number_keyword (yyvsp[-1].num, yyvsp[0].num)) {
 					    twmrc_error_prefix();
 					    fprintf (stderr,
 				"unknown numeric keyword %d (value %d)\n",
-						     (yyvsp[-1].num), (yyvsp[0].num));
+						     yyvsp[-1].num, yyvsp[0].num);
 					    ParseError = 1;
 					  }
 					}
@@ -1822,12 +1789,12 @@ yyreduce:
 
   case 78:
 #line 311 "gram.y"
-    { (yyval.num) = (yyvsp[0].num); }
+    { yyval.num = yyvsp[0].num; }
     break;
 
   case 79:
 #line 314 "gram.y"
-    { (yyval.num) = (yyvsp[0].num); }
+    { yyval.num = yyvsp[0].num; }
     break;
 
   case 82:
@@ -1852,14 +1819,14 @@ yyreduce:
 
   case 86:
 #line 325 "gram.y"
-    { if ((yyvsp[0].num) < 1 || (yyvsp[0].num) > 5) {
+    { if (yyvsp[0].num < 1 || yyvsp[0].num > 5) {
 					     twmrc_error_prefix();
 					     fprintf (stderr, 
 				"bad modifier number (%d), must be 1-5\n",
-						      (yyvsp[0].num));
+						      yyvsp[0].num);
 					     ParseError = 1;
 					  } else {
-					     mods |= (Mod1Mask << ((yyvsp[0].num) - 1));
+					     mods |= (Mod1Mask << (yyvsp[0].num - 1));
 					  }
 					}
     break;
@@ -1961,154 +1928,154 @@ yyreduce:
 
   case 110:
 #line 366 "gram.y"
-    { Name = (yyvsp[0].ptr); cont |= C_NAME_BIT; }
+    { Name = yyvsp[0].ptr; cont |= C_NAME_BIT; }
     break;
 
   case 114:
 #line 377 "gram.y"
-    { SetHighlightPixmap ((yyvsp[0].ptr)); }
+    { SetHighlightPixmap (yyvsp[0].ptr); }
     break;
 
   case 118:
 #line 388 "gram.y"
     {
-			NewBitmapCursor(&Scr->FrameCursor, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+			NewBitmapCursor(&Scr->FrameCursor, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 119:
 #line 390 "gram.y"
     {
-			NewFontCursor(&Scr->FrameCursor, (yyvsp[0].ptr)); }
+			NewFontCursor(&Scr->FrameCursor, yyvsp[0].ptr); }
     break;
 
   case 120:
 #line 392 "gram.y"
     {
-			NewBitmapCursor(&Scr->TitleCursor, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+			NewBitmapCursor(&Scr->TitleCursor, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 121:
 #line 394 "gram.y"
     {
-			NewFontCursor(&Scr->TitleCursor, (yyvsp[0].ptr)); }
+			NewFontCursor(&Scr->TitleCursor, yyvsp[0].ptr); }
     break;
 
   case 122:
 #line 396 "gram.y"
     {
-			NewBitmapCursor(&Scr->IconCursor, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+			NewBitmapCursor(&Scr->IconCursor, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 123:
 #line 398 "gram.y"
     {
-			NewFontCursor(&Scr->IconCursor, (yyvsp[0].ptr)); }
+			NewFontCursor(&Scr->IconCursor, yyvsp[0].ptr); }
     break;
 
   case 124:
 #line 400 "gram.y"
     {
-			NewBitmapCursor(&Scr->IconMgrCursor, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+			NewBitmapCursor(&Scr->IconMgrCursor, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 125:
 #line 402 "gram.y"
     {
-			NewFontCursor(&Scr->IconMgrCursor, (yyvsp[0].ptr)); }
+			NewFontCursor(&Scr->IconMgrCursor, yyvsp[0].ptr); }
     break;
 
   case 126:
 #line 404 "gram.y"
     {
-			NewBitmapCursor(&Scr->ButtonCursor, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+			NewBitmapCursor(&Scr->ButtonCursor, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 127:
 #line 406 "gram.y"
     {
-			NewFontCursor(&Scr->ButtonCursor, (yyvsp[0].ptr)); }
+			NewFontCursor(&Scr->ButtonCursor, yyvsp[0].ptr); }
     break;
 
   case 128:
 #line 408 "gram.y"
     {
-			NewBitmapCursor(&Scr->MoveCursor, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+			NewBitmapCursor(&Scr->MoveCursor, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 129:
 #line 410 "gram.y"
     {
-			NewFontCursor(&Scr->MoveCursor, (yyvsp[0].ptr)); }
+			NewFontCursor(&Scr->MoveCursor, yyvsp[0].ptr); }
     break;
 
   case 130:
 #line 412 "gram.y"
     {
-			NewBitmapCursor(&Scr->ResizeCursor, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+			NewBitmapCursor(&Scr->ResizeCursor, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 131:
 #line 414 "gram.y"
     {
-			NewFontCursor(&Scr->ResizeCursor, (yyvsp[0].ptr)); }
+			NewFontCursor(&Scr->ResizeCursor, yyvsp[0].ptr); }
     break;
 
   case 132:
 #line 416 "gram.y"
     {
-			NewBitmapCursor(&Scr->WaitCursor, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+			NewBitmapCursor(&Scr->WaitCursor, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 133:
 #line 418 "gram.y"
     {
-			NewFontCursor(&Scr->WaitCursor, (yyvsp[0].ptr)); }
+			NewFontCursor(&Scr->WaitCursor, yyvsp[0].ptr); }
     break;
 
   case 134:
 #line 420 "gram.y"
     {
-			NewBitmapCursor(&Scr->MenuCursor, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+			NewBitmapCursor(&Scr->MenuCursor, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 135:
 #line 422 "gram.y"
     {
-			NewFontCursor(&Scr->MenuCursor, (yyvsp[0].ptr)); }
+			NewFontCursor(&Scr->MenuCursor, yyvsp[0].ptr); }
     break;
 
   case 136:
 #line 424 "gram.y"
     {
-			NewBitmapCursor(&Scr->SelectCursor, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+			NewBitmapCursor(&Scr->SelectCursor, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 137:
 #line 426 "gram.y"
     {
-			NewFontCursor(&Scr->SelectCursor, (yyvsp[0].ptr)); }
+			NewFontCursor(&Scr->SelectCursor, yyvsp[0].ptr); }
     break;
 
   case 138:
 #line 428 "gram.y"
     {
-			NewBitmapCursor(&Scr->DestroyCursor, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+			NewBitmapCursor(&Scr->DestroyCursor, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 139:
 #line 430 "gram.y"
     {
-			NewFontCursor(&Scr->DestroyCursor, (yyvsp[0].ptr)); }
+			NewFontCursor(&Scr->DestroyCursor, yyvsp[0].ptr); }
     break;
 
   case 143:
 #line 442 "gram.y"
-    { if (!do_colorlist_keyword ((yyvsp[-1].num), color,
-								     (yyvsp[0].ptr))) {
+    { if (!do_colorlist_keyword (yyvsp[-1].num, color,
+								     yyvsp[0].ptr)) {
 					    twmrc_error_prefix();
 					    fprintf (stderr,
 			"unhandled list color keyword %d (string \"%s\")\n",
-						     (yyvsp[-1].num), (yyvsp[0].ptr));
+						     yyvsp[-1].num, yyvsp[0].ptr);
 					    ParseError = 1;
 					  }
 					}
@@ -2116,13 +2083,13 @@ yyreduce:
 
   case 144:
 #line 451 "gram.y"
-    { list = do_colorlist_keyword((yyvsp[-1].num),color,
-								      (yyvsp[0].ptr));
+    { list = do_colorlist_keyword(yyvsp[-1].num,color,
+								      yyvsp[0].ptr);
 					  if (!list) {
 					    twmrc_error_prefix();
 					    fprintf (stderr,
 			"unhandled color list keyword %d (string \"%s\")\n",
-						     (yyvsp[-1].num), (yyvsp[0].ptr));
+						     yyvsp[-1].num, yyvsp[0].ptr);
 					    ParseError = 1;
 					  }
 					}
@@ -2135,12 +2102,12 @@ yyreduce:
 
   case 146:
 #line 462 "gram.y"
-    { if (!do_color_keyword ((yyvsp[-1].num), color,
-								 (yyvsp[0].ptr))) {
+    { if (!do_color_keyword (yyvsp[-1].num, color,
+								 yyvsp[0].ptr)) {
 					    twmrc_error_prefix();
 					    fprintf (stderr,
 			"unhandled color keyword %d (string \"%s\")\n",
-						     (yyvsp[-1].num), (yyvsp[0].ptr));
+						     yyvsp[-1].num, yyvsp[0].ptr);
 					    ParseError = 1;
 					  }
 					}
@@ -2148,19 +2115,19 @@ yyreduce:
 
   case 150:
 #line 480 "gram.y"
-    { do_string_savecolor(color, (yyvsp[0].ptr)); }
+    { do_string_savecolor(color, yyvsp[0].ptr); }
     break;
 
   case 151:
 #line 481 "gram.y"
-    { do_var_savecolor((yyvsp[0].num)); }
+    { do_var_savecolor(yyvsp[0].num); }
     break;
 
   case 155:
 #line 491 "gram.y"
     { if (Scr->FirstTime &&
 					      color == Scr->Monochrome)
-					    AddToList(list, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+					    AddToList(list, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 156:
@@ -2192,7 +2159,7 @@ yyreduce:
 #line 510 "gram.y"
     {
 				if (Scr->FirstTime) {
-				   do_squeeze_entry (list, (yyvsp[-3].ptr), (yyvsp[-2].num), (yyvsp[-1].num), (yyvsp[0].num));
+				   do_squeeze_entry (list, yyvsp[-3].ptr, yyvsp[-2].num, yyvsp[-1].num, yyvsp[0].num);
 				}
 			}
     break;
@@ -2200,36 +2167,36 @@ yyreduce:
   case 167:
 #line 525 "gram.y"
     { if (Scr->FirstTime)
-					    AddToList(list, (yyvsp[-2].ptr), (char *)
-						AllocateIconManager((yyvsp[-2].ptr), NULLSTR,
-							(yyvsp[-1].ptr),(yyvsp[0].num)));
+					    AddToList(list, yyvsp[-2].ptr, (char *)
+						AllocateIconManager(yyvsp[-2].ptr, NULLSTR,
+							yyvsp[-1].ptr,yyvsp[0].num));
 					}
     break;
 
   case 168:
 #line 531 "gram.y"
     { if (Scr->FirstTime)
-					    AddToList(list, (yyvsp[-3].ptr), (char *)
-						AllocateIconManager((yyvsp[-3].ptr),(yyvsp[-2].ptr),
-						(yyvsp[-1].ptr), (yyvsp[0].num)));
+					    AddToList(list, yyvsp[-3].ptr, (char *)
+						AllocateIconManager(yyvsp[-3].ptr,yyvsp[-2].ptr,
+						yyvsp[-1].ptr, yyvsp[0].num));
 					}
     break;
 
   case 172:
 #line 545 "gram.y"
     { if (Scr->FirstTime)
-					    AddToList(list, (yyvsp[0].ptr), 0);
+					    AddToList(list, yyvsp[0].ptr, 0);
 					}
     break;
 
   case 176:
 #line 557 "gram.y"
-    { if (Scr->FirstTime) AddToList(list, (yyvsp[-1].ptr), (yyvsp[0].ptr)); }
+    { if (Scr->FirstTime) AddToList(list, yyvsp[-1].ptr, yyvsp[0].ptr); }
     break;
 
   case 180:
 #line 567 "gram.y"
-    { AddToMenu(root, "", Action, NULL, (yyvsp[0].num),
+    { AddToMenu(root, "", Action, NULL, yyvsp[0].num,
 						NULLSTR, NULLSTR);
 					  Action = "";
 					}
@@ -2237,7 +2204,7 @@ yyreduce:
 
   case 184:
 #line 580 "gram.y"
-    { AddToMenu(root, (yyvsp[-1].ptr), Action, pull, (yyvsp[0].num),
+    { AddToMenu(root, yyvsp[-1].ptr, Action, pull, yyvsp[0].num,
 						NULLSTR, NULLSTR);
 					  Action = "";
 					  pull = NULL;
@@ -2247,8 +2214,8 @@ yyreduce:
   case 185:
 #line 585 "gram.y"
     {
-					  AddToMenu(root, (yyvsp[-6].ptr), Action, pull, (yyvsp[0].num),
-						(yyvsp[-4].ptr), (yyvsp[-2].ptr));
+					  AddToMenu(root, yyvsp[-6].ptr, Action, pull, yyvsp[0].num,
+						yyvsp[-4].ptr, yyvsp[-2].ptr);
 					  Action = "";
 					  pull = NULL;
 					}
@@ -2256,17 +2223,17 @@ yyreduce:
 
   case 186:
 #line 593 "gram.y"
-    { (yyval.num) = (yyvsp[0].num); }
+    { yyval.num = yyvsp[0].num; }
     break;
 
   case 187:
 #line 594 "gram.y"
     {
-				(yyval.num) = (yyvsp[-1].num);
-				Action = (yyvsp[0].ptr);
-				switch ((yyvsp[-1].num)) {
+				yyval.num = yyvsp[-1].num;
+				Action = yyvsp[0].ptr;
+				switch (yyvsp[-1].num) {
 				  case F_MENU:
-				    pull = GetRoot ((yyvsp[0].ptr), NULLSTR,NULLSTR);
+				    pull = GetRoot (yyvsp[0].ptr, NULLSTR,NULLSTR);
 				    pull->prev = root;
 				    break;
 				  case F_WARPRING:
@@ -2275,7 +2242,7 @@ yyreduce:
 					fprintf (stderr,
 			"ignoring invalid f.warptoring argument \"%s\"\n",
 						 Action);
-					(yyval.num) = F_NOP;
+					yyval.num = F_NOP;
 				    }
 				  case F_WARPTOSCREEN:
 				    if (!CheckWarpScreenArg (Action)) {
@@ -2283,18 +2250,18 @@ yyreduce:
 					fprintf (stderr, 
 			"ignoring invalid f.warptoscreen argument \"%s\"\n", 
 					         Action);
-					(yyval.num) = F_NOP;
+					yyval.num = F_NOP;
 				    }
 				    break;
 				  case F_COLORMAP:
 				    if (CheckColormapArg (Action)) {
-					(yyval.num) = F_COLORMAP;
+					yyval.num = F_COLORMAP;
 				    } else {
 					twmrc_error_prefix();
 					fprintf (stderr,
 			"ignoring invalid f.colormap argument \"%s\"\n", 
 						 Action);
-					(yyval.num) = F_NOP;
+					yyval.num = F_NOP;
 				    }
 				    break;
 				} /* end switch */
@@ -2303,28 +2270,28 @@ yyreduce:
 
   case 188:
 #line 635 "gram.y"
-    { (yyval.num) = (yyvsp[0].num); }
+    { yyval.num = yyvsp[0].num; }
     break;
 
   case 189:
 #line 636 "gram.y"
-    { (yyval.num) = (yyvsp[0].num); }
+    { yyval.num = yyvsp[0].num; }
     break;
 
   case 190:
 #line 637 "gram.y"
-    { (yyval.num) = -((yyvsp[0].num)); }
+    { yyval.num = -(yyvsp[0].num); }
     break;
 
   case 191:
 #line 640 "gram.y"
-    { (yyval.num) = (yyvsp[0].num);
-					  if ((yyvsp[0].num) == 0)
+    { yyval.num = yyvsp[0].num;
+					  if (yyvsp[0].num == 0)
 						yyerror("bad button 0");
 
-					  if ((yyvsp[0].num) > MAX_BUTTONS)
+					  if (yyvsp[0].num > MAX_BUTTONS)
 					  {
-						(yyval.num) = 0;
+						yyval.num = 0;
 						yyerror("button number too large");
 					  }
 					}
@@ -2332,23 +2299,23 @@ yyreduce:
 
   case 192:
 #line 652 "gram.y"
-    { ptr = (char *)malloc(strlen((yyvsp[0].ptr))+1);
-					  strcpy(ptr, (yyvsp[0].ptr));
+    { ptr = (char *)malloc(strlen(yyvsp[0].ptr)+1);
+					  strcpy(ptr, yyvsp[0].ptr);
 					  RemoveDQuote(ptr);
-					  (yyval.ptr) = ptr;
+					  yyval.ptr = ptr;
 					}
     break;
 
   case 193:
 #line 658 "gram.y"
-    { (yyval.num) = (yyvsp[0].num); }
+    { yyval.num = yyvsp[0].num; }
     break;
 
 
     }
 
-/* Line 1037 of yacc.c.  */
-#line 2352 "gram.c"
+/* Line 993 of yacc.c.  */
+#line 2319 "gram.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2448,7 +2415,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2458,22 +2425,23 @@ yyerrlab:
 	  if (yychar == YYEOF)
 	     for (;;)
 	       {
-
 		 YYPOPSTACK;
 		 if (yyssp == yyss)
 		   YYABORT;
-		 yydestruct ("Error: popping",
-                             yystos[*yyssp], yyvsp);
+		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+		 yydestruct (yystos[*yyssp], yyvsp);
 	       }
         }
       else
 	{
-	  yydestruct ("Error: discarding", yytoken, &yylval);
+	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
+	  yydestruct (yytoken, &yylval);
 	  yychar = YYEMPTY;
+
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2490,7 +2458,7 @@ yyerrorlab:
      goto yyerrorlab;
 #endif
 
-yyvsp -= yylen;
+  yyvsp -= yylen;
   yyssp -= yylen;
   yystate = *yyssp;
   goto yyerrlab1;
@@ -2520,8 +2488,8 @@ yyerrlab1:
       if (yyssp == yyss)
 	YYABORT;
 
-
-      yydestruct ("Error: popping", yystos[yystate], yyvsp);
+      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+      yydestruct (yystos[yystate], yyvsp);
       YYPOPSTACK;
       yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
@@ -2530,12 +2498,11 @@ yyerrlab1:
   if (yyn == YYFINAL)
     YYACCEPT;
 
+  YYDPRINTF ((stderr, "Shifting error token, "));
+
   *++yyvsp = yylval;
 
 
-  /* Shift the error token. */
-  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);
-
   yystate = yyn;
   goto yynewstate;
 
@@ -2551,9 +2518,6 @@ yyacceptlab:
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
 yyabortlab:
-  yydestruct ("Error: discarding lookahead",
-              yytoken, &yylval);
-  yychar = YYEMPTY;
   yyresult = 1;
   goto yyreturn;
 
